
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
DROLSKY
DROLSKY's
Rolsky
Rolsky's
AE
AO
API
AQ
Aland
BD
BG
BH
BJ
BN
BQ
BT
BW
BZ
Barthelemy
Bolivarian
Bonaire
Burkina
CN
CPAN
CX
CY
Cabo
Caicos
Costa
Cunha
DK
DM
Darussalam
DateTime
EE
EG
El
Eustatius
FI
FJ
FK
FO
Faroe
Faso
FromEnv
Futuna
GF
GG
GH
GL
GN
GQ
GW
GY
HK
HN
HU
Hong
IM
JE
JM
Jamahiriya
KE
KH
KI
KZ
Kitts
LK
LV
LY
Lanka
Leone
Leste
MF
MH
MQ
MX
MZ
Maarten
Malvinas
Marino
Mayen
Mayotte
Millenium
Miquelon
NG
NL
Niue
PN
PY
Palau
Papua
PayPal
Plurinational
Puerto
QA
RO
RW
Rata
Rica
SG
SL
SV
SX
SY
SZ
Saba
Sao
Sint
Sri
Storable
Subclass
Subclasses
TF
TG
TJ
TK
TT
TW
TZ
Timor
Tokelau
UA
UG
UIs
UTC
UY
UZ
VC
VE
VMS
VN
VU
Viet
WF
WS
XP
ZA
ZM
ZW
Zealand
d'Ivoire
da
datetime
env
pre
subclasses
timezones
versa
Dave
autarch
Alexey
Molchanov
alexey
Alfie
John
alfiej
Daisuke
Maki
dmaki
David
Pinkowitz
dave
Iain
Truskett
deceased
Joshua
Hoblitt
jhoblitt
Karen
Etheridge
ether
Peter
Rabbitson
ribasushi
lib
TimeZone
MST7MDT
Asia
Dili
America
Hermosillo
Indian
Kerguelen
Pacific
Wallis
OlsonDB
Observance
Resolute
Dawson_Creek
Reunion
Pohnpei
Krasnoyarsk
Argentina
Mendoza
Rankin_Inlet
Atlantic
Stanley
San_Juan
Montevideo
San_Luis
Europe
Bucharest
Tahiti
Africa
Casablanca
Yakutat
Aqtobe
Port_of_Spain
Shanghai
CST6CDT
Qyzylorda
Rarotonga
Antarctica
Davis
Brunei
Cordoba
Guayaquil
Bahrain
Karachi
Tegucigalpa
Windhoek
Kosrae
Ashgabat
Rio_Gallegos
Moscow
Gambier
Boise
HST
Atikokan
Macau
Edmonton
Syowa
Manaus
Rome
Campo_Grande
Belgrade
Local
Unix
Hebron
Port_Moresby
Swift_Current
Kabul
Auckland
Efate
Colombo
Whitehorse
Vilnius
Chihuahua
Jujuy
Port_au_Prince
Macquarie
Buenos_Aires
Bahia_Banderas
Novosibirsk
Scoresbysund
Samarkand
Anadyr
Azores
Pontianak
Dubai
Malta
Yakutsk
Kolkata
Beirut
Cuiaba
La_Rioja
Fakaofo
Cayenne
Berlin
Australia
Sydney
Denver
Riga
Indiana
Vincennes
Vancouver
Monrovia
Uzhgorod
North_Dakota
New_Salem
El_Aaiun
Panama
Minsk
Chuuk
Singapore
Taipei
Marquesas
EST5EDT
Ceuta
Eirunepe
EST
Tongatapu
Boa_Vista
Dushanbe
Andorra
Adak
Rothera
El_Salvador
Curacao
Santa_Isabel
Tokyo
Thunder_Bay
Merida
Simferopol
Bishkek
Enderbury
Brussels
Pyongyang
Perth
Muscat
Cocos
Lima
Oslo
Kuching
Tallinn
London
Jayapura
Kentucky
Louisville
Martinique
Managua
Chicago
Tehran
Nicosia
Creston
Nassau
South_Georgia
Salta
Mauritius
Maputo
Marengo
Monterrey
PST8PDT
Bahia
Tripoli
Santiago
Araguaina
Omsk
Mahe
Samara
Tarawa
Broken_Hill
Iqaluit
Kamchatka
Gibraltar
Mexico_City
Christmas
Kathmandu
Glace_Bay
Noronha
Magadan
Recife
Ojinaga
Rule
Lisbon
Porto_Velho
Nauru
Chatham
Paris
Khandyga
Guatemala
Noumea
Funafuti
Belize
Mawson
Cancun
Easter
Monaco
Casey
Hovd
Troll
Budapest
Pago_Pago
Manila
Sofia
Amman
Los_Angeles
Johannesburg
Norfolk
Puerto_Rico
Anchorage
Guam
Rainy_River
Sao_Paulo
Caracas
Ulaanbaatar
Bissau
Inuvik
Srednekolymsk
MST
Sakhalin
Indianapolis
Amsterdam
Vienna
Majuro
Godthab
Istanbul
Nome
Lindeman
Rio_Branco
New_York
Jerusalem
Athens
Maldives
Cayman
Change
Brisbane
Kaliningrad
Toronto
La_Paz
Jakarta
Darwin
Zurich
Chagos
Guyana
Android
Asuncion
Bermuda
MET
Winamac
Madrid
Urumqi
Dawson
Nipigon
Irkutsk
Kiev
Antigua
Honolulu
Choibalsan
Ust_Nera
Catalog
Maceio
Warsaw
Thule
Pitcairn
Kwajalein
CET
WET
Helsinki
Oral
Petersburg
Luxembourg
St_Johns
Hobart
Eucla
OffsetOnly
Tashkent
Bogota
Fortaleza
Tunis
Abidjan
Qatar
Tell_City
Havana
Danmarkshavn
Zaporozhye
Madeira
Cambridge_Bay
Ushuaia
Vladivostok
Aden
Currie
Moncton
Menominee
Lagos
Dhaka
Pangnirtung
Kuwait
Fiji
Tucuman
Volgograd
Santo_Domingo
Belem
Phoenix
Ndjamena
Saipan
Winnipeg
Gaza
Catamarca
Tbilisi
Apia
Prague
Blanc_Sablon
Yerevan
Reykjavik
Chita
Bougainville
Thimphu
Sitka
Juneau
Midway
Barbados
Nairobi
Riyadh
Kuala_Lumpur
Halifax
Makassar
Zone
Galapagos
Tijuana
Knox
Hong_Kong
Seoul
Adelaide
Montreal
Center
Detroit
Cairo
Novokuznetsk
Grand_Turk
Mazatlan
Melbourne
Guadalcanal
DumontDUrville
Rangoon
Yellowknife
Vostok
Khartoum
Ho_Chi_Minh
Matamoros
Cape_Verde
Dublin
Metlakatla
EET
Accra
Algiers
Chisinau
Yekaterinburg
Aqtau
Monticello
Floating
Costa_Rica
Goose_Bay
Santarem
Wake
Baghdad
Beulah
Canary
Palmer
Tirane
Paramaribo
Jamaica
Stockholm
Bangkok
Vevay
Damascus
Regina
Baku
Lord_Howe
Kiritimati
Almaty
Copenhagen
